Learn R Programming

lapmix (version 1.38.0)

lap.volcanoplot: Laplace Volcano Plot

Description

Creates a volcano plot of log-fold changes versus log-odds of differential expression under the Laplace mixture model.

Usage

lap.volcanoplot(res, highlight=0, ...)

Arguments

res
the output from the lapmix.Fit routine
highlight
number of genes to be highlighted; genes are highlighted in descending order of their posterior odds
...
additional arguments given to the plot function

Value

Details

A volcano plot is any plot which displays fold changes versus a measure of statistical significance of the change.

Examples

Run this code
#  See lapmix.Fit example

Run the code above in your browser using DataLab